@@ -411,7 +411,7 @@ owner_change_callback (GtkClipboard        *clipboard,
 }
 
 static void
-target_destroy_callback (GtkObject *object,
+target_destroy_callback (GtkWidget *object,
 			 gpointer callback_data)
 {
 	TargetCallbackData *target_data;
@@ -419,7 +419,7 @@ target_destroy_callback (GtkObject *object,
 	g_assert (callback_data != NULL);
 	target_data = callback_data;
 
-	if (clipboard_items_are_merged_in (GTK_WIDGET(object))) {
+	if (clipboard_items_are_merged_in (object)) {
 		merge_out_clipboard_menu_items (G_OBJECT (object), callback_data);
 	}
 }
