@@ -113,12 +113,6 @@ nautilus_open_with_dialog_finalize (GObject *object)
 	G_OBJECT_CLASS (nautilus_open_with_dialog_parent_class)->finalize (object);
 }
 
-static void
-nautilus_open_with_dialog_destroy (GtkObject *object)
-{
-	GTK_OBJECT_CLASS (nautilus_open_with_dialog_parent_class)->destroy (object);
-}
-
 /* An application is valid if:
  *
  * 1) The file exists
@@ -359,17 +353,13 @@ static void
 nautilus_open_with_dialog_class_init (NautilusOpenWithDialogClass *class)
 {
 	GObjectClass *gobject_class;
-	GtkObjectClass *object_class;
 
 	gobject_class = G_OBJECT_CLASS (class);
 	gobject_class->finalize = nautilus_open_with_dialog_finalize;
 
-	object_class = GTK_OBJECT_CLASS (class);
-	object_class->destroy = nautilus_open_with_dialog_destroy;
-
 	signals[APPLICATION_SELECTED] =
 		g_signal_new ("application_selected",
-			      G_TYPE_FROM_CLASS (object_class),
+			      G_TYPE_FROM_CLASS (class),
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (NautilusOpenWithDialogClass,
 					       application_selected),
@@ -778,7 +768,6 @@ nautilus_open_with_dialog_init (NautilusOpenWithDialog *dialog)
 	dialog->details = g_new0 (NautilusOpenWithDialogDetails, 1);
 
 	gtk_window_set_title (GTK_WINDOW (dialog), _("Open With"));
-	gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
 	gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
 	gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
 	gtk_window_set_destroy_with_parent (GTK_WINDOW (dialog), TRUE);
