@@ -35,10 +35,8 @@
 #include "fm-tree-model.h"
 #include "fm-properties-window.h"
 #include <string.h>
-#include <eel/eel-alert-dialog.h>
 #include <eel/eel-glib-extensions.h>
 #include <eel/eel-gtk-extensions.h>
-#include <eel/eel-preferences.h>
 #include <eel/eel-stock-dialogs.h>
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
@@ -54,7 +52,6 @@
 #include <libnautilus-private/nautilus-icon-names.h>
 #include <libnautilus-private/nautilus-program-choosing.h>
 #include <libnautilus-private/nautilus-tree-view-drag-dest.h>
-#include <libnautilus-private/nautilus-cell-renderer-pixbuf-emblem.h>
 #include <libnautilus-private/nautilus-sidebar-provider.h>
 #include <libnautilus-private/nautilus-module.h>
 #include <libnautilus-private/nautilus-window-info.h>
@@ -114,7 +111,6 @@ typedef struct {
 } PrependURIParameters;
 
 static GdkAtom copied_files_atom;
-static gboolean show_delete_command_auto_value;
 
 static void  fm_tree_view_iface_init        (NautilusSidebarIface         *iface);
 static void  sidebar_provider_iface_init    (NautilusSidebarProviderIface *iface);
@@ -744,7 +740,7 @@ button_pressed_callback (GtkTreeView *treeview, GdkEventButton *event,
 		can_move_file_to_trash = nautilus_file_can_trash (view->details->popup_file);
 		gtk_widget_set_sensitive (view->details->popup_trash, can_move_file_to_trash);
 		
-		if (show_delete_command_auto_value) {
+		if (g_settings_get_boolean (nautilus_preferences, NAUTILUS_PREFERENCES_ENABLE_DELETE)) {
 			parent_file_is_writable = is_parent_writable (view->details->popup_file);
 			file_is_home_or_desktop = nautilus_file_is_home (view->details->popup_file)
 				|| nautilus_file_is_desktop_directory (view->details->popup_file);
@@ -1044,7 +1040,7 @@ fm_tree_view_delete_cb (GtkWidget *menu_item,
 {
 	GList *location_list;
 		
-	if (!show_delete_command_auto_value) {
+	if (!g_settings_get_boolean (nautilus_preferences, NAUTILUS_PREFERENCES_ENABLE_DELETE)) {
 		return;
 	}
 	
@@ -1375,13 +1371,12 @@ create_tree (FMTreeView *view)
 	/* Create column */
 	column = gtk_tree_view_column_new ();
 
-	cell = nautilus_cell_renderer_pixbuf_emblem_new ();
+	cell = gtk_cell_renderer_pixbuf_new ();
 	gtk_tree_view_column_pack_start (column, cell, FALSE);
 	gtk_tree_view_column_set_attributes (column, cell,
 					     "pixbuf", FM_TREE_MODEL_CLOSED_PIXBUF_COLUMN,
 					     "pixbuf_expander_closed", FM_TREE_MODEL_CLOSED_PIXBUF_COLUMN,
 					     "pixbuf_expander_open", FM_TREE_MODEL_OPEN_PIXBUF_COLUMN,
-					     "pixbuf_emblem", FM_TREE_MODEL_EMBLEM_PIXBUF_COLUMN,
 					     NULL);
 	
 	cell = gtk_cell_renderer_text_new ();
@@ -1419,7 +1414,7 @@ static void
 update_filtering_from_preferences (FMTreeView *view)
 {
 	NautilusWindowShowHiddenFilesMode mode;
-	
+
 	if (view->details->child_model == NULL) {
 		return;
 	}
@@ -1429,7 +1424,7 @@ update_filtering_from_preferences (FMTreeView *view)
 	if (mode == NAUTILUS_WINDOW_SHOW_HIDDEN_FILES_DEFAULT) {
 		fm_tree_model_set_show_hidden_files
 			(view->details->child_model,
-			 eel_preferences_get_boolean (NAUTILUS_PREFERENCES_SHOW_HIDDEN_FILES));
+			 g_settings_get_boolean (nautilus_preferences, NAUTILUS_PREFERENCES_SHOW_HIDDEN_FILES));
 	} else {
 		fm_tree_model_set_show_hidden_files
 			(view->details->child_model,
@@ -1437,7 +1432,8 @@ update_filtering_from_preferences (FMTreeView *view)
 	}
 	fm_tree_model_set_show_only_directories
 		(view->details->child_model,
-		 eel_preferences_get_boolean (NAUTILUS_PREFERENCES_TREE_SHOW_ONLY_DIRECTORIES));
+		 g_settings_get_boolean (nautilus_tree_sidebar_preferences,
+					 NAUTILUS_PREFERENCES_TREE_SHOW_ONLY_DIRECTORIES));
 }
 
 static void
@@ -1493,19 +1489,21 @@ fm_tree_view_init (FMTreeView *view)
 	
 	view->details->selecting = FALSE;
 
-	eel_preferences_add_callback_while_alive (NAUTILUS_PREFERENCES_SHOW_HIDDEN_FILES,
-						  filtering_changed_callback, view, G_OBJECT (view));
-	eel_preferences_add_callback_while_alive (NAUTILUS_PREFERENCES_SHOW_BACKUP_FILES,
-						  filtering_changed_callback, view, G_OBJECT (view));
-	eel_preferences_add_callback_while_alive (NAUTILUS_PREFERENCES_TREE_SHOW_ONLY_DIRECTORIES,
-						  filtering_changed_callback, view, G_OBJECT (view));
-	
+	g_signal_connect_swapped (nautilus_preferences,
+				  "changed::" NAUTILUS_PREFERENCES_SHOW_HIDDEN_FILES,
+				  G_CALLBACK(filtering_changed_callback),
+				  view);
+
+	g_signal_connect_swapped (nautilus_tree_sidebar_preferences,
+				  "changed::" NAUTILUS_PREFERENCES_TREE_SHOW_ONLY_DIRECTORIES,
+				  G_CALLBACK (filtering_changed_callback), view);
+
 	view->details->popup_file = NULL;
 
-	view->details->clipboard_handler_id = 
+	view->details->clipboard_handler_id =
 		g_signal_connect (nautilus_clipboard_monitor_get (),
-		                  "clipboard_info",
-		                  G_CALLBACK (notify_clipboard_info), view);
+				  "clipboard_info",
+				  G_CALLBACK (notify_clipboard_info), view);
 }
 
 static void
@@ -1563,6 +1561,13 @@ fm_tree_view_dispose (GObject *object)
 		view->details->volume_monitor = NULL;
 	}
 
+	g_signal_handlers_disconnect_by_func (nautilus_preferences,
+					      G_CALLBACK(filtering_changed_callback),
+					      view);
+	g_signal_handlers_disconnect_by_func (nautilus_tree_sidebar_preferences,
+					      G_CALLBACK(filtering_changed_callback),
+					      view);
+
 	view->details->window = NULL;
 
 	G_OBJECT_CLASS (parent_class)->dispose (object);
@@ -1585,11 +1590,8 @@ fm_tree_view_class_init (FMTreeViewClass *class)
 {
 	G_OBJECT_CLASS (class)->dispose = fm_tree_view_dispose;
 	G_OBJECT_CLASS (class)->finalize = fm_tree_view_finalize;
-	
-	copied_files_atom = gdk_atom_intern ("x-special/gnome-copied-files", FALSE);
 
-	eel_preferences_add_auto_boolean (NAUTILUS_PREFERENCES_ENABLE_DELETE,
-					  &show_delete_command_auto_value);	
+	copied_files_atom = gdk_atom_intern ("x-special/gnome-copied-files", FALSE);
 }
 
 static const char *
