@@ -35,11 +35,9 @@
 #if ENABLE_EMPTY_VIEW
 #include "file-manager/fm-empty-view.h"
 #endif /* ENABLE_EMPTY_VIEW */
-#include "nautilus-information-panel.h"
 #include "nautilus-history-sidebar.h"
 #include "nautilus-places-sidebar.h"
 #include "nautilus-notes-viewer.h"
-#include "nautilus-emblem-sidebar.h"
 #include "nautilus-image-properties-page.h"
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -77,14 +75,10 @@
 #include <libnautilus-extension/nautilus-menu-provider.h>
 #include <libnautilus-private/nautilus-autorun.h>
 
-enum
-{
-  COMMAND_0, /* unused: 0 is an invalid command */
-
-  COMMAND_START_DESKTOP,
-  COMMAND_STOP_DESKTOP,
-  COMMAND_OPEN_BROWSER,
-};
+#define COMMAND_OPEN "open"
+#define COMMAND_START_DESKTOP "start_desktop"
+#define COMMAND_STOP_DESKTOP "stop_desktop"
+#define COMMAND_CLOSE "close"
 
 /* Keep window from shrinking down ridiculously small; numbers are somewhat arbitrary */
 #define APPLICATION_WINDOW_MIN_WIDTH	300
@@ -127,73 +121,6 @@ static char *   nautilus_application_get_session_data (void);
 
 G_DEFINE_TYPE (NautilusApplication, nautilus_application, G_TYPE_OBJECT);
 
-static gboolean
-_unique_message_data_set_geometry_and_uris (UniqueMessageData  *message_data,
-					    const char *geometry,
-					    char **uris)
-{
-  GString *list;
-  gint i;
-  gchar *result;
-  gsize length;
-
-  list = g_string_new (NULL);
-  if (geometry != NULL) {
-	  g_string_append (list, geometry);
-  }
-  g_string_append (list, "\r\n");
-  
-  for (i = 0; uris != NULL && uris[i]; i++) {
-	  g_string_append (list, uris[i]);
-	  g_string_append (list, "\r\n");
-  }
-
-  result = g_convert (list->str, list->len,
-                      "ASCII", "UTF-8",
-                      NULL, &length, NULL);
-  g_string_free (list, TRUE);
-  
-  if (result) {
-	  unique_message_data_set (message_data, (guchar *) result, length);
-	  g_free (result);
-	  return TRUE;
-  }
-  
-  return FALSE;
-}
-
-static gchar **
-_unique_message_data_get_geometry_and_uris (UniqueMessageData *message_data,
-					    char **geometry)
-{
-  gchar **result = NULL;
-
-  *geometry = NULL;
-  
-  gchar *text, *newline, *uris;
-  text = unique_message_data_get_text (message_data);
-  if (text) {
-	  newline = strchr (text, '\n');
-	  if (newline) {
-		  *geometry = g_strndup (text, newline-text);
-		  uris = newline+1;
-	  } else {
-		  uris = text;
-	  }
-	  
-	  result = g_uri_list_extract_uris (uris);
-	  g_free (text);
-  }
-
-  /* if the string is empty, make it NULL */
-  if (*geometry && strlen (*geometry) == 0) {
-	  g_free (*geometry);
-	  *geometry = NULL;
-  }
-
-  return result;
-}
-
 GList *
 nautilus_application_get_window_list (void)
 {
@@ -227,8 +154,8 @@ automount_all_volumes (NautilusApplication *application)
 	GList *volumes, *l;
 	GMount *mount;
 	GVolume *volume;
-		
-	if (eel_preferences_get_boolean (NAUTILUS_PREFERENCES_MEDIA_AUTOMOUNT)) {
+
+	if (g_settings_get_boolean (nautilus_media_preferences, NAUTILUS_PREFERENCES_MEDIA_AUTOMOUNT)) {
 		/* automount all mountable volumes at start-up */
 		volumes = g_volume_monitor_get_volumes (application->volume_monitor);
 		for (l = volumes; l != NULL; l = l->next) {
@@ -283,13 +210,6 @@ nautilus_application_init (NautilusApplication *application)
 	/* Create an undo manager */
 	application->undo_manager = nautilus_undo_manager_new ();
 
-	application->unique_app = unique_app_new_with_commands ("org.gnome.Nautilus", NULL,
-								"start_desktop", COMMAND_START_DESKTOP,
-								"stop_desktop", COMMAND_STOP_DESKTOP,
-								"open_browser", COMMAND_OPEN_BROWSER,
-								NULL);
-
-	
         application->smclient = egg_sm_client_get ();
         g_signal_connect (application->smclient, "save_state",
                           G_CALLBACK (smclient_save_state_cb),
@@ -310,11 +230,9 @@ nautilus_application_init (NautilusApplication *application)
 
 	/* register sidebars */
 	nautilus_places_sidebar_register ();
-	nautilus_information_panel_register ();
 	fm_tree_view_register ();
 	nautilus_history_sidebar_register ();
 	nautilus_notes_viewer_register (); /* also property page */
-	nautilus_emblem_sidebar_register ();
 
 	/* register property pages */
 	nautilus_image_properties_page_register ();
@@ -353,9 +271,9 @@ nautilus_application_finalize (GObject *object)
 		application->automount_idle_id = 0;
 	}
 
-	if (application->ck_watch_id != 0) {
-		g_bus_unwatch_proxy (application->ck_watch_id);
-		application->ck_watch_id = 0;
+	if (application->proxy != NULL) {
+		g_object_unref (application->proxy);
+		application->proxy = NULL;
 	}
 
         G_OBJECT_CLASS (nautilus_application_parent_class)->finalize (object);
@@ -417,7 +335,7 @@ check_required_directories (NautilusApplication *application)
 
 		dialog = eel_show_error_dialog (error_string, detail_string, NULL);
 		/* We need the main event loop so the user has a chance to see the dialog. */
-		nautilus_main_event_loop_register (GTK_OBJECT (dialog));
+		nautilus_main_event_loop_register (GTK_WIDGET (dialog));
 
 		g_string_free (directories_as_string, TRUE);
 		g_free (error_string);
@@ -566,23 +484,23 @@ ck_call_is_active_cb (GDBusProxy   *proxy,
 }
 
 static void
-session_proxy_vanished (GDBusConnection *connection,
-                        const gchar *name,
-                        gpointer user_data)
+session_proxy_appeared (GObject       *source,
+                        GAsyncResult *res,
+                        gpointer      user_data)
 {
 	NautilusApplication *application = user_data;
+        GDBusProxy *proxy;
+	GError *error = NULL;
 
-	application->session_is_active = TRUE;
-}
+        proxy = g_dbus_proxy_new_for_bus_finish (res, &error);
 
-static void
-session_proxy_appeared (GDBusConnection *connection,
-                        const gchar *name,
-                        const gchar *name_owner,
-                        GDBusProxy *proxy,
-                        gpointer user_data)
-{
-	NautilusApplication *application = user_data;
+	if (error != NULL) {
+		g_warning ("Failed to get the current CK session: %s", error->message);
+		g_error_free (error);
+
+		application->session_is_active = TRUE;
+		return;
+	}
 
 	g_signal_connect (proxy, "g-signal",
 			  G_CALLBACK (ck_session_proxy_signal_cb),
@@ -595,7 +513,9 @@ session_proxy_appeared (GDBusConnection *connection,
 			   -1,
 			   NULL,
 			   (GAsyncReadyCallback) ck_call_is_active_cb,
-			   application);	
+			   application);
+
+        application->proxy = proxy;
 }
 
 static void
@@ -620,16 +540,15 @@ ck_get_current_session_cb (GDBusConnection *connection,
 
 	g_variant_get (variant, "(&o)", &session_path);
 
-	application->ck_watch_id = g_bus_watch_proxy (G_BUS_TYPE_SYSTEM,
-						      CK_NAME,
-						      0, session_path,
-						      CK_INTERFACE ".Session",
-						      G_TYPE_DBUS_PROXY,
-						      G_DBUS_PROXY_FLAGS_DO_NOT_LOAD_PROPERTIES,
-						      session_proxy_appeared,
-						      session_proxy_vanished,
-						      application,
-						      NULL);
+	g_dbus_proxy_new_for_bus (G_BUS_TYPE_SYSTEM,
+				  G_DBUS_PROXY_FLAGS_NONE,
+				  NULL,
+				  CK_NAME,
+				  session_path,
+				  CK_INTERFACE ".Session",
+				  NULL,
+				  session_proxy_appeared,
+				  application);
 
 	g_variant_unref (variant);
 }
@@ -695,7 +614,7 @@ do_upgrades_once (NautilusApplication *application,
 	if (g_file_test (nautilus_dir, G_FILE_TEST_IS_DIR)) {
 		/* test if we already attempted to migrate first */
 		updated = g_build_filename (nautilus_dir, "DEPRECATED-DIRECTORY", NULL);
-		message = _("Nautilus 2.32 deprecated this directory and tried migrating "
+		message = _("Nautilus 3.0 deprecated this directory and tried migrating "
 			    "this configuration to ~/.config/nautilus");
 		if (!g_file_test (updated, G_FILE_TEST_EXISTS)) {
 			/* rename() works fine if the destination directory is
@@ -777,34 +696,34 @@ open_window (NautilusApplication *application,
 {
 	GFile *location;
 	NautilusWindow *window;
+	gboolean existing;
+
+	if (uri == NULL) {
+		location = g_file_new_for_path (g_get_home_dir ());
+	} else {
+		location = g_file_new_for_uri (uri);
+	}
+
+	existing = FALSE;
 
 	if (browser_window ||
-	    eel_preferences_get_boolean (NAUTILUS_PREFERENCES_ALWAYS_USE_BROWSER)) {
+	    g_settings_get_boolean (nautilus_preferences, NAUTILUS_PREFERENCES_ALWAYS_USE_BROWSER)) {
 		window = nautilus_application_create_navigation_window (application,
 									startup_id,
 									screen);
-		if (uri == NULL) {
-			nautilus_window_go_home (window);
-		} else {
-			location = g_file_new_for_uri (uri);
-			nautilus_window_go_to (window, location);
-			g_object_unref (location);
-		}
 	} else {
-		if (uri == NULL) {
-			location = g_file_new_for_path (g_get_home_dir ());
-		} else {
-			location = g_file_new_for_uri (uri);
-		}
-		
-		window = nautilus_application_present_spatial_window (application,
-								      NULL,
-								      startup_id,
-								      location,
-								      screen);
-		g_object_unref (location);
+		window = nautilus_application_get_spatial_window (application,
+								  NULL,
+								  startup_id,
+								  location,
+								  screen,
+								  NULL);
 	}
-	
+
+	nautilus_window_go_to (window, location);
+
+	g_object_unref (location);
+
 	if (geometry != NULL && !gtk_widget_get_visible (GTK_WIDGET (window))) {
 		/* never maximize windows opened from shell if a
 		 * custom geometry has been requested.
@@ -839,53 +758,65 @@ open_windows (NautilusApplication *application,
 	}
 }
 
-static UniqueResponse
-message_received_cb (UniqueApp         *unique_app,
-                     UniqueCommand      command,
-                     UniqueMessageData *message,
-                     guint              time_,
-                     gpointer           user_data)
+static void
+message_received_cb (GApplication *unique_app,
+		     gchar *name,
+		     GVariant *platform_data,
+		     gpointer user_data)
 {
 	NautilusApplication *application;
-	UniqueResponse res;
-	char **uris;
-	char *geometry;
-	GdkScreen *screen;
-	
+
 	application =  user_data;
-	res = UNIQUE_RESPONSE_OK;
-	
-	switch (command) {
-	case UNIQUE_CLOSE:
-		res = UNIQUE_RESPONSE_OK;
+
+	if (g_strcmp0 (name, COMMAND_CLOSE) == 0) {
 		nautilus_main_event_loop_quit (TRUE);
-		
-		break;
-	case UNIQUE_OPEN:
-	case COMMAND_OPEN_BROWSER:
-		uris = _unique_message_data_get_geometry_and_uris (message, &geometry);
-		screen = unique_message_data_get_screen (message);
+		return;
+	}
+
+	if (g_strcmp0 (name, COMMAND_OPEN) == 0) {
+		GVariantIter iter;
+		gboolean use_browser;
+		gchar *key;
+		GVariant *value;
+		gchar *startup_id = NULL, *geometry = NULL;
+		char **uris = NULL;
+
+		g_variant_iter_init (&iter, platform_data);
+
+		while (g_variant_iter_next (&iter, "{&sv}", &key, &value)) {
+			if (g_strcmp0 (key, "urls") == 0) {
+				g_variant_get (value, "^as", &uris);
+			} else if (g_strcmp0 (key, "geometry") == 0) {
+				g_variant_get (value, "&s", &geometry);
+			} else if (g_strcmp0 (key, "use_browser") == 0) {
+				g_variant_get (value, "b", &use_browser);
+			} else if (g_strcmp0 (key, "startup_id") == 0) {
+				g_variant_get (value, "&s", &startup_id);
+			}
+
+			g_variant_unref (value);
+		}
+
 		open_windows (application,
-			      unique_message_data_get_startup_id (message),
+			      startup_id,
 			      uris,
-			      screen,
+			      gdk_screen_get_default (),
 			      geometry,
-			      command == COMMAND_OPEN_BROWSER);
+			      use_browser);
 		g_strfreev (uris);
-		g_free (geometry);
-		break;
-	case COMMAND_START_DESKTOP:
+
+		return;
+	}
+
+	if (g_strcmp0 (name, COMMAND_START_DESKTOP) == 0) {
 		nautilus_application_open_desktop (application);
-		break;
-	case COMMAND_STOP_DESKTOP:
+		return;
+	}
+
+	if (g_strcmp0 (name, COMMAND_STOP_DESKTOP) == 0) {
 		nautilus_application_close_desktop ();
-		break;
-	default:
-		res = UNIQUE_RESPONSE_PASSTHROUGH;
-		break;
+		return;
 	}
-	
-	return res;
 }
 
 gboolean 
@@ -917,6 +848,34 @@ queue_accel_map_save_callback (GtkAccelMap *object, gchar *accel_path,
 	}
 }
 
+static GVariant *
+get_startup_id (void)
+{
+	gchar *id = NULL;
+	GVariant *retval;
+	GTimeVal timeval = { 0, };
+
+	id = g_strdup (gdk_x11_display_get_startup_notification_id (gdk_display_get_default ()));
+
+	if (id == NULL) {
+		id = g_strdup (g_getenv ("DESKTOP_STARTUP_ID"));
+	}
+
+	if (id == NULL) {
+		guint32 timestamp;
+
+		g_get_current_time (&timeval);
+
+		timestamp =  timeval.tv_sec;
+		id = g_strdup_printf ("_TIME%lu", (unsigned long) timestamp);
+        }
+
+	retval = g_variant_new ("s", id);
+	g_free (id);
+
+	return retval;
+}
+
 void
 nautilus_application_startup (NautilusApplication *application,
 			      gboolean kill_shell,
@@ -926,8 +885,9 @@ nautilus_application_startup (NautilusApplication *application,
 			      const char *geometry,
 			      char **urls)
 {
-	UniqueMessageData *message;
-	
+	gboolean is_remote;
+	GError *error = NULL;
+
 	/* Check the user's ~/.nautilus directories and post warnings
 	 * if there are problems.
 	 */
@@ -935,60 +895,95 @@ nautilus_application_startup (NautilusApplication *application,
 		return;
 	}
 
+	application->unique_app = g_initable_new (G_TYPE_APPLICATION,
+						  NULL,
+						  &error,
+						  "application-id", "org.gnome.Nautilus",
+						  "default-quit", FALSE,
+						  "argv", g_variant_new_bytestring_array (NULL, 0),
+						  NULL);
+	g_assert (error == NULL);
+	is_remote = g_application_is_remote (application->unique_app);
+
+	if (!is_remote) {
+		/* set application properties */
+		g_application_add_action (application->unique_app,
+					  "open", "Open a nautilus window");
+		g_application_add_action (application->unique_app,
+					  "close", "Close the application");
+		g_application_add_action (application->unique_app,
+					  COMMAND_START_DESKTOP, "Starts the desktop");
+		g_application_add_action (application->unique_app,
+					  COMMAND_STOP_DESKTOP, "Stops the desktop");
+	}
+
 	if (kill_shell) {
-		if (unique_app_is_running (application->unique_app)) {
-			unique_app_send_message (application->unique_app,
-						 UNIQUE_CLOSE, NULL);
-			
+		if (is_remote) {
+			g_application_invoke_action (application->unique_app,
+						     COMMAND_CLOSE, NULL);
 		}
 	} else {
 		char *accel_map_filename;
 
 		if (!no_desktop &&
-		    !eel_preferences_get_boolean (NAUTILUS_PREFERENCES_SHOW_DESKTOP)) {
+		    !g_settings_get_boolean (nautilus_preferences, NAUTILUS_PREFERENCES_SHOW_DESKTOP)) {
 			no_desktop = TRUE;
 		}
-			
+
 		if (!no_desktop) {
-			if (unique_app_is_running (application->unique_app)) {
-				unique_app_send_message (application->unique_app,
-							 COMMAND_START_DESKTOP, NULL);
+			if (is_remote) {
+				g_application_invoke_action (application->unique_app,
+							     COMMAND_START_DESKTOP, NULL);
 			} else {
 				nautilus_application_open_desktop (application);
 			}
 		}
 
-		if (!unique_app_is_running (application->unique_app)) {
+		if (!is_remote) {
 			finish_startup (application, no_desktop);
-			g_signal_connect (application->unique_app, "message-received", G_CALLBACK (message_received_cb), application);			
+			g_signal_connect (application->unique_app,
+					  "action-with-data",
+					  G_CALLBACK (message_received_cb), application);			
 		}
-		
+
 		/* Monitor the preference to show or hide the desktop */
-		eel_preferences_add_callback_while_alive (NAUTILUS_PREFERENCES_SHOW_DESKTOP,
-							  desktop_changed_callback,
-							  application,
-							  G_OBJECT (application));
+		g_signal_connect_swapped (nautilus_preferences, "changed::" NAUTILUS_PREFERENCES_SHOW_DESKTOP,
+					  G_CALLBACK(desktop_changed_callback),
+					  G_OBJECT (application));
 
 		/* Monitor the preference to have the desktop */
 		/* point to the Unix home folder */
-		eel_preferences_add_callback_while_alive (NAUTILUS_PREFERENCES_DESKTOP_IS_HOME_DIR,
-							  desktop_location_changed_callback,
-							  NULL,
-							  G_OBJECT (application));
+		g_signal_connect_swapped (nautilus_preferences, "changed::" NAUTILUS_PREFERENCES_DESKTOP_IS_HOME_DIR,
+					  G_CALLBACK(desktop_location_changed_callback),
+					  G_OBJECT (application));
 
-	  	/* Create the other windows. */
+		/* Create the other windows. */
 		if (urls != NULL || !no_default_window) {
-			if (unique_app_is_running (application->unique_app)) {
-				message = unique_message_data_new ();
-				_unique_message_data_set_geometry_and_uris (message, geometry, urls);
-				if (browser_window) {
-					unique_app_send_message (application->unique_app,
-								 COMMAND_OPEN_BROWSER, message);
-				} else {
-					unique_app_send_message (application->unique_app,
-								 UNIQUE_OPEN, message);
+			if (is_remote) {
+				GVariant *variant;
+				GVariantBuilder builder;
+
+				g_variant_builder_init (&builder, G_VARIANT_TYPE ("a{sv}"));
+
+				if (geometry != NULL) {
+					g_variant_builder_add (&builder, "{sv}",
+							       "geometry", g_variant_new ("s", geometry));
 				}
-				unique_message_data_free (message);				
+
+				if (urls != NULL) {
+					g_variant_builder_add (&builder, "{sv}",
+							       "urls", g_variant_new ("^as", urls));
+				}
+
+				g_variant_builder_add (&builder, "{sv}",
+						       "use_browser", g_variant_new ("b", browser_window));
+				g_variant_builder_add (&builder, "{sv}",
+						       "startup_id", get_startup_id ());
+				variant = g_variant_builder_end (&builder);
+
+				g_application_invoke_action (application->unique_app,
+							     COMMAND_OPEN, variant);
+				g_variant_unref (variant);
 			} else {
 				open_windows (application, NULL,
 					      urls,
@@ -1046,7 +1041,7 @@ get_desktop_manager_selection (GdkDisplay *display, int screen)
 	if (gtk_selection_owner_set_for_display (display,
 						 selection_widget,
 						 selection_atom,
-						 gdk_x11_get_server_time (selection_widget->window))) {
+						 gdk_x11_get_server_time (gtk_widget_get_window (selection_widget)))) {
 		
 		g_signal_connect (selection_widget, "selection_get",
 				  G_CALLBACK (selection_get_cb), NULL);
@@ -1152,6 +1147,17 @@ nautilus_application_close_all_navigation_windows (void)
 	GList *l;
 	
 	list_copy = g_list_copy (nautilus_application_window_list);
+	/* First hide all window to get the feeling of quick response */
+	for (l = list_copy; l != NULL; l = l->next) {
+		NautilusWindow *window;
+		
+		window = NAUTILUS_WINDOW (l->data);
+
+		if (NAUTILUS_IS_NAVIGATION_WINDOW (window)) {
+			gtk_widget_hide (GTK_WIDGET (window));
+		}
+	}
+
 	for (l = list_copy; l != NULL; l = l->next) {
 		NautilusWindow *window;
 		
@@ -1169,19 +1175,25 @@ nautilus_application_get_existing_spatial_window (GFile *location)
 {
 	GList *l;
 	NautilusWindowSlot *slot;
+	GFile *window_location;
 
 	for (l = nautilus_application_get_spatial_window_list ();
 	     l != NULL; l = l->next) {
-		GFile *window_location;
-
 		slot = NAUTILUS_WINDOW (l->data)->details->active_pane->active_slot;
-		window_location = slot->location;
+
+		window_location = slot->pending_location;
+		
+		if (window_location == NULL) {
+			window_location = slot->location;
+		}
+
 		if (window_location != NULL) {
 			if (g_file_equal (location, window_location)) {
 				return NAUTILUS_SPATIAL_WINDOW (l->data);
 			}
 		}
 	}
+
 	return NULL;
 }
 
@@ -1259,6 +1271,17 @@ nautilus_application_close_all_spatial_windows (void)
 	GList *l;
 	
 	list_copy = g_list_copy (nautilus_application_spatial_window_list);
+	/* First hide all window to get the feeling of quick response */
+	for (l = list_copy; l != NULL; l = l->next) {
+		NautilusWindow *window;
+		
+		window = NAUTILUS_WINDOW (l->data);
+		
+		if (NAUTILUS_IS_SPATIAL_WINDOW (window)) {
+			gtk_widget_hide (GTK_WIDGET (window));
+		}
+	}
+
 	for (l = list_copy; l != NULL; l = l->next) {
 		NautilusWindow *window;
 		
@@ -1272,7 +1295,7 @@ nautilus_application_close_all_spatial_windows (void)
 }
 
 static void
-nautilus_application_destroyed_window (GtkObject *object, NautilusApplication *application)
+nautilus_application_destroyed_window (GtkWidget *object, NautilusApplication *application)
 {
 	nautilus_application_window_list = g_list_remove (nautilus_application_window_list, object);
 }
@@ -1335,62 +1358,31 @@ spatial_window_destroyed_callback (void *user_data, GObject *window)
 }
 
 NautilusWindow *
-nautilus_application_present_spatial_window (NautilusApplication *application,
-					     NautilusWindow      *requesting_window,
-					     const char          *startup_id,
-					     GFile               *location,
-					     GdkScreen           *screen)
-{
-	return nautilus_application_present_spatial_window_with_selection (application,
-									   requesting_window,
-									   startup_id,
-									   location,
-									   NULL,
-									   screen);
-}
-
-NautilusWindow *
-nautilus_application_present_spatial_window_with_selection (NautilusApplication *application,
-							    NautilusWindow      *requesting_window,
-							    const char          *startup_id,
-							    GFile               *location,
-							    GList		*new_selection,
-							    GdkScreen           *screen)
+nautilus_application_get_spatial_window (NautilusApplication *application,
+					 NautilusWindow      *requesting_window,
+					 const char          *startup_id,
+					 GFile               *location,
+					 GdkScreen           *screen,
+					 gboolean            *existing)
 {
 	NautilusWindow *window;
-	GList *l;
-	char *uri;
+	gchar *uri;
 
 	g_return_val_if_fail (NAUTILUS_IS_APPLICATION (application), NULL);
-	
-	for (l = nautilus_application_get_spatial_window_list ();
-	     l != NULL; l = l->next) {
-		NautilusWindow *existing_window;
-		NautilusWindowSlot *slot;
-		GFile *existing_location;
 
-		existing_window = NAUTILUS_WINDOW (l->data);
-		slot = existing_window->details->active_pane->active_slot;
-		existing_location = slot->pending_location;
-		
-		if (existing_location == NULL) {
-			existing_location = slot->location;
-		}
-		
-		if (g_file_equal (existing_location, location)) {
-			gtk_window_present (GTK_WINDOW (existing_window));
-			if (new_selection &&
-			    slot->content_view != NULL) {
-				nautilus_view_set_selection (slot->content_view, new_selection);
-			}
+	window = NAUTILUS_WINDOW
+		(nautilus_application_get_existing_spatial_window (location));
 
-			uri = g_file_get_uri (location);
-			nautilus_debug_log (FALSE, NAUTILUS_DEBUG_LOG_DOMAIN_USER,
-					    "present EXISTING spatial window=%p: %s",
-					    existing_window, uri);
-			g_free (uri);
-			return existing_window;
+	if (window != NULL) {
+		if (existing != NULL) {
+			*existing = TRUE;
 		}
+
+		return window;
+	}
+
+	if (existing != NULL) {
+		*existing = FALSE;
 	}
 
 	window = create_window (application, NAUTILUS_TYPE_SPATIAL_WINDOW, startup_id, screen);
@@ -1420,8 +1412,6 @@ nautilus_application_present_spatial_window_with_selection (NautilusApplication
 	nautilus_application_spatial_window_list = g_list_prepend (nautilus_application_spatial_window_list, window);
 	g_object_weak_ref (G_OBJECT (window), 
 			   spatial_window_destroyed_callback, NULL);
-	
-	nautilus_window_go_to_with_selection (window, location, new_selection);
 
 	uri = g_file_get_uri (location);
 	nautilus_debug_log (FALSE, NAUTILUS_DEBUG_LOG_DOMAIN_USER,
@@ -1458,19 +1448,19 @@ nautilus_application_create_navigation_window (NautilusApplication *application,
 	gboolean maximized;
 
 	g_return_val_if_fail (NAUTILUS_IS_APPLICATION (application), NULL);
-	
+
 	window = create_window (application, NAUTILUS_TYPE_NAVIGATION_WINDOW, startup_id, screen);
 
-	maximized = eel_preferences_get_boolean
-			(NAUTILUS_PREFERENCES_NAVIGATION_WINDOW_MAXIMIZED);
+	maximized = g_settings_get_boolean
+		(nautilus_window_state, NAUTILUS_WINDOW_STATE_MAXIMIZED);
 	if (maximized) {
 		gtk_window_maximize (GTK_WINDOW (window));
 	} else {
 		gtk_window_unmaximize (GTK_WINDOW (window));
 	}
 
-	geometry_string = eel_preferences_get
-			(NAUTILUS_PREFERENCES_NAVIGATION_WINDOW_SAVED_GEOMETRY);
+	geometry_string = g_settings_get_string
+		(nautilus_window_state, NAUTILUS_WINDOW_STATE_GEOMETRY);
 	if (geometry_string != NULL &&
 	    geometry_string[0] != 0) {
 		/* Ignore saved window position if a window with the same
@@ -1508,9 +1498,9 @@ static void
 desktop_changed_callback (gpointer user_data)
 {
 	NautilusApplication *application;
-	
+
 	application = NAUTILUS_APPLICATION (user_data);
-	if ( eel_preferences_get_boolean (NAUTILUS_PREFERENCES_SHOW_DESKTOP)) {
+	if (g_settings_get_boolean (nautilus_preferences, NAUTILUS_PREFERENCES_SHOW_DESKTOP)) {
 		nautilus_application_open_desktop (application);
 	} else {
 		nautilus_application_close_desktop ();
@@ -1532,7 +1522,7 @@ volume_added_callback (GVolumeMonitor *monitor,
 		       GVolume *volume,
 		       NautilusApplication *application)
 {
-	if (eel_preferences_get_boolean (NAUTILUS_PREFERENCES_MEDIA_AUTOMOUNT) &&
+	if (g_settings_get_boolean (nautilus_media_preferences, NAUTILUS_PREFERENCES_MEDIA_AUTOMOUNT) &&
 	    g_volume_should_automount (volume) &&
 	    g_volume_can_mount (volume)) {
 		nautilus_file_operations_mount_volume (NULL, volume, TRUE);
@@ -1601,24 +1591,28 @@ autorun_show_window (GMount *mount, gpointer user_data)
 {
 	GFile *location;
 	NautilusApplication *application = user_data;
-	
+	NautilusWindow *window;
+	gboolean existing;
+
 	location = g_mount_get_root (mount);
-	
-	/* Ther should probably be an easier way to do this */
-	if (eel_preferences_get_boolean (NAUTILUS_PREFERENCES_ALWAYS_USE_BROWSER)) {
-		NautilusWindow *window;
+	existing = FALSE;
+
+	/* There should probably be an easier way to do this */
+	if (g_settings_get_boolean (nautilus_preferences, NAUTILUS_PREFERENCES_ALWAYS_USE_BROWSER)) {
 		window = nautilus_application_create_navigation_window (application, 
 									NULL, 
 									gdk_screen_get_default ());
-		nautilus_window_go_to (window, location);
-
 	} else {
-		nautilus_application_present_spatial_window (application, 
-							     NULL, 
-							     NULL, 
-							     location, 
-							     gdk_screen_get_default ());
+		window = nautilus_application_get_spatial_window (application,
+								  NULL,
+								  NULL,
+								  location,
+								  gdk_screen_get_default (),
+								  NULL);
 	}
+
+	nautilus_window_go_to (window, location);
+
 	g_object_unref (location);
 }
 
@@ -1860,22 +1854,26 @@ nautilus_application_get_session_data (void)
 		xmlNewProp (win_node, "type", NAUTILUS_IS_NAVIGATION_WINDOW (window) ? "navigation" : "spatial");
 
 		if (NAUTILUS_IS_NAVIGATION_WINDOW (window)) { /* spatial windows store their state as file metadata */
+			GdkWindow *gdk_window;
+
 			tmp = eel_gtk_window_get_geometry_string (GTK_WINDOW (window));
 			xmlNewProp (win_node, "geometry", tmp);
 			g_free (tmp);
 
-			if (GTK_WIDGET (window)->window &&
-			    gdk_window_get_state (GTK_WIDGET (window)->window) & GDK_WINDOW_STATE_MAXIMIZED) {
+			gdk_window = gtk_widget_get_window (GTK_WIDGET (window));
+
+			if (gdk_window &&
+			    gdk_window_get_state (gdk_window) & GDK_WINDOW_STATE_MAXIMIZED) {
 				xmlNewProp (win_node, "maximized", "TRUE");
 			}
 
-			if (GTK_WIDGET (window)->window &&
-			    gdk_window_get_state (GTK_WIDGET (window)->window) & GDK_WINDOW_STATE_STICKY) {
+			if (gdk_window &&
+			    gdk_window_get_state (gdk_window) & GDK_WINDOW_STATE_STICKY) {
 				xmlNewProp (win_node, "sticky", "TRUE");
 			}
 
-			if (GTK_WIDGET (window)->window &&
-			    gdk_window_get_state (GTK_WIDGET (window)->window) & GDK_WINDOW_STATE_ABOVE) {
+			if (gdk_window &&
+			    gdk_window_get_state (gdk_window) & GDK_WINDOW_STATE_ABOVE) {
 				xmlNewProp (win_node, "keep-above", "TRUE");
 			}
 		}
@@ -2095,7 +2093,12 @@ nautilus_application_load_session (NautilusApplication *application)
 					}
 				} else if (!strcmp (type, "spatial")) {
 					location = g_file_new_for_uri (location_uri);
-					window = nautilus_application_present_spatial_window (application, NULL, NULL, location, gdk_screen_get_default ());
+					window = nautilus_application_get_spatial_window (application, NULL, NULL,
+											  location, gdk_screen_get_default (),
+											  NULL);
+
+					nautilus_window_go_to (window, location);
+
 					g_object_unref (location);
 				} else {
 					g_message ("unknown window type \"%s\" while parsing session data", type);
