@@ -30,7 +30,6 @@
 #include <eel/eel-debug.h>
 #include <eel/eel-gtk-extensions.h>
 #include <eel/eel-glib-extensions.h>
-#include <eel/eel-preferences.h>
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
 #include <libnautilus-private/nautilus-bookmark.h>
@@ -208,9 +207,9 @@ static void
 update_click_policy (NautilusHistorySidebar *sidebar)
 {
 	int policy;
-	
-	policy = eel_preferences_get_enum (NAUTILUS_PREFERENCES_CLICK_POLICY);
-	
+
+	policy = g_settings_get_enum (nautilus_preferences, NAUTILUS_PREFERENCES_CLICK_POLICY);
+
 	eel_gtk_tree_view_set_activate_on_single_click
 		(sidebar->tree_view, policy == NAUTILUS_CLICK_POLICY_SINGLE);
 }
@@ -268,6 +267,7 @@ nautilus_history_sidebar_init (NautilusHistorySidebar *sidebar)
 					GTK_POLICY_AUTOMATIC);
 	gtk_scrolled_window_set_hadjustment (GTK_SCROLLED_WINDOW (sidebar), NULL);
 	gtk_scrolled_window_set_vadjustment (GTK_SCROLLED_WINDOW (sidebar), NULL);
+	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (sidebar), GTK_SHADOW_IN);
 	gtk_container_add (GTK_CONTAINER (sidebar), GTK_WIDGET (tree_view));
 	gtk_widget_show (GTK_WIDGET (sidebar));
 	
@@ -287,9 +287,10 @@ nautilus_history_sidebar_init (NautilusHistorySidebar *sidebar)
 	g_signal_connect (tree_view, "button-press-event", 
 			  G_CALLBACK (button_press_event_callback), sidebar);
 
-	eel_preferences_add_callback (NAUTILUS_PREFERENCES_CLICK_POLICY,
-				      click_policy_changed_callback,
-				      sidebar);
+	g_signal_connect_swapped (nautilus_preferences,
+				  "changed::" NAUTILUS_PREFERENCES_CLICK_POLICY,
+				  G_CALLBACK(click_policy_changed_callback),
+				  sidebar);
 	update_click_policy (sidebar);
 }
 
@@ -297,12 +298,11 @@ static void
 nautilus_history_sidebar_finalize (GObject *object)
 {
 	NautilusHistorySidebar *sidebar;
-	
+
 	sidebar = NAUTILUS_HISTORY_SIDEBAR (object);
 
-	eel_preferences_remove_callback (NAUTILUS_PREFERENCES_CLICK_POLICY,
-					 click_policy_changed_callback,
-					 sidebar);
+	g_signal_handlers_disconnect_by_func (nautilus_preferences,
+					      click_policy_changed_callback, sidebar);
 
 	G_OBJECT_CLASS (nautilus_history_sidebar_parent_class)->finalize (object);
 }
