@@ -38,7 +38,6 @@
 #include "nautilus-bookmark-list.h"
 #include "nautilus-bookmarks-window.h"
 #include "nautilus-file-management-properties.h"
-#include "nautilus-property-browser.h"
 #include "nautilus-window-manage-views.h"
 #include "nautilus-window-private.h"
 #include "nautilus-window-bookmarks.h"
@@ -47,7 +46,6 @@
 #include <eel/eel-gnome-extensions.h>
 #include <eel/eel-stock-dialogs.h>
 #include <eel/eel-string.h>
-#include <eel/eel-xml-extensions.h>
 #include <libxml/parser.h>
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
@@ -115,7 +113,7 @@ forget_history_if_yes (GtkDialog *dialog, int response, gpointer callback_data)
 	if (response == RESPONSE_FORGET) {
 		nautilus_forget_history ();
 	}
-	gtk_object_destroy (GTK_OBJECT (dialog));
+	gtk_widget_destroy (GTK_WIDGET (dialog));
 }
 
 static void
@@ -321,7 +319,7 @@ nautilus_navigation_window_update_spatial_menu_item (NautilusNavigationWindow *w
 	action = gtk_action_group_get_action (window->details->navigation_action_group,
 					      NAUTILUS_ACTION_FOLDER_WINDOW);
 	gtk_action_set_visible (action,
-				!eel_preferences_get_boolean (NAUTILUS_PREFERENCES_ALWAYS_USE_BROWSER));
+				!g_settings_get_boolean (nautilus_preferences, NAUTILUS_PREFERENCES_ALWAYS_USE_BROWSER));
 }
 
 static void
@@ -585,56 +583,32 @@ action_new_tab_callback (GtkAction *action,
 			 gpointer user_data)
 {
 	NautilusWindow *window;
-	NautilusWindowSlot *current_slot;
-	NautilusWindowSlot *new_slot;
-	NautilusWindowOpenFlags flags;
-	GFile *location;
-	int new_slot_position;
-	char *scheme;
 
 	window = NAUTILUS_WINDOW (user_data);
-	current_slot = window->details->active_pane->active_slot;
-	location = nautilus_window_slot_get_location (current_slot);
-
-	if (location != NULL) {
-		flags = 0;
-
-		new_slot_position = eel_preferences_get_enum (NAUTILUS_PREFERENCES_NEW_TAB_POSITION);
-		if (new_slot_position == NAUTILUS_NEW_TAB_POSITION_END) {
-			flags = NAUTILUS_WINDOW_OPEN_SLOT_APPEND;
-		}
-
-		scheme = g_file_get_uri_scheme (location);
-		if (!strcmp (scheme, "x-nautilus-search")) {
-			g_object_unref (location);
-			location = g_file_new_for_path (g_get_home_dir ());
-		}
-		g_free (scheme);
-
-		new_slot = nautilus_window_open_slot (current_slot->pane, flags);
-		nautilus_window_set_active_slot (window, new_slot);
-		nautilus_window_slot_go_to (new_slot, location, FALSE);
-		g_object_unref (location);
-	}
+	nautilus_window_new_tab (window);
 }
 
 static void
 action_folder_window_callback (GtkAction *action,
 			       gpointer user_data)
 {
-	NautilusWindow *current_window;
+	NautilusWindow *current_window, *window;
 	NautilusWindowSlot *slot;
 	GFile *current_location;
 
 	current_window = NAUTILUS_WINDOW (user_data);
 	slot = current_window->details->active_pane->active_slot;
 	current_location = nautilus_window_slot_get_location (slot);
-	nautilus_application_present_spatial_window (
-			current_window->application,
-			current_window,
-			NULL,
-			current_location,
-			gtk_window_get_screen (GTK_WINDOW (current_window)));
+	window = nautilus_application_get_spatial_window
+		(current_window->application,
+		 current_window,
+		 NULL,
+		 current_location,
+		 gtk_window_get_screen (GTK_WINDOW (current_window)),
+		 NULL);
+
+	nautilus_window_go_to (window, current_location);
+
 	if (current_location != NULL) {
 		g_object_unref (current_location);
 	}
