@@ -23,7 +23,6 @@
 #include <eel/eel-debug.h>
 #include <eel/eel-gtk-extensions.h>
 #include <eel/eel-glib-extensions.h>
-#include <eel/eel-preferences.h>
 #include <eel/eel-string.h>
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
@@ -33,7 +32,6 @@
 #include <libnautilus-private/nautilus-global-preferences.h>
 #include <libnautilus-private/nautilus-icon-names.h>
 #include <libnautilus-private/nautilus-trash-monitor.h>
-#include <libnautilus-private/nautilus-marshal.h>
 #include <libnautilus-private/nautilus-dnd.h>
 #include <libnautilus-private/nautilus-icon-dnd.h>
 #include "nautilus-pathbar.h"
@@ -304,10 +302,9 @@ nautilus_path_bar_init (NautilusPathBar *path_bar)
 	path_bar->root_path = g_file_new_for_path ("/");
 	desktop_is_home = g_file_equal (path_bar->home_path, path_bar->desktop_path);
 
-	eel_preferences_add_callback_while_alive (NAUTILUS_PREFERENCES_DESKTOP_IS_HOME_DIR,
-						  desktop_location_changed_callback,
-						  path_bar,
-						  G_OBJECT (path_bar));
+	g_signal_connect_swapped (nautilus_preferences, "changed::" NAUTILUS_PREFERENCES_DESKTOP_IS_HOME_DIR,
+				  G_CALLBACK(desktop_location_changed_callback),
+				  path_bar);
 
         g_signal_connect_swapped (path_bar->up_slider_button, "clicked", G_CALLBACK (nautilus_path_bar_scroll_up), path_bar);
         g_signal_connect_swapped (path_bar->down_slider_button, "clicked", G_CALLBACK (nautilus_path_bar_scroll_down), path_bar);
@@ -351,12 +348,10 @@ static void
 nautilus_path_bar_class_init (NautilusPathBarClass *path_bar_class)
 {
         GObjectClass *gobject_class;
-        GtkObjectClass *object_class;
         GtkWidgetClass *widget_class;
         GtkContainerClass *container_class;
 
         gobject_class = (GObjectClass *) path_bar_class;
-        object_class = (GtkObjectClass *) path_bar_class;
         widget_class = (GtkWidgetClass *) path_bar_class;
         container_class = (GtkContainerClass *) path_bar_class;
 
@@ -378,7 +373,7 @@ nautilus_path_bar_class_init (NautilusPathBarClass *path_bar_class)
 
         path_bar_signals [PATH_CLICKED] =
                 g_signal_new ("path-clicked",
-		  G_OBJECT_CLASS_TYPE (object_class),
+		  G_OBJECT_CLASS_TYPE (path_bar_class),
 		  G_SIGNAL_RUN_FIRST,
 		  G_STRUCT_OFFSET (NautilusPathBarClass, path_clicked),
 		  NULL, NULL,
@@ -387,7 +382,7 @@ nautilus_path_bar_class_init (NautilusPathBarClass *path_bar_class)
 		  G_TYPE_FILE);
 	 path_bar_signals [PATH_SET] =
 		g_signal_new ("path-set",
-		  G_OBJECT_CLASS_TYPE (object_class),
+		  G_OBJECT_CLASS_TYPE (path_bar_class),
 		  G_SIGNAL_RUN_FIRST,
 		  G_STRUCT_OFFSET (NautilusPathBarClass, path_set),
 		  NULL, NULL,
@@ -427,6 +422,9 @@ nautilus_path_bar_finalize (GObject *object)
 
 	g_signal_handlers_disconnect_by_func (nautilus_trash_monitor_get (),
 					      trash_state_changed_cb, path_bar);
+	g_signal_handlers_disconnect_by_func (nautilus_preferences,
+					      desktop_location_changed_callback,
+					      path_bar);
 
         G_OBJECT_CLASS (nautilus_path_bar_parent_class)->finalize (object);
 }
@@ -476,7 +474,8 @@ nautilus_path_bar_size_request (GtkWidget      *widget,
 
 	for (list = path_bar->button_list; list; list = list->next) {
 		button_data = BUTTON_DATA (list->data);
-                gtk_widget_size_request (button_data->button, &child_requisition);
+		gtk_widget_get_preferred_size (button_data->button,
+					       &child_requisition, NULL);
                 requisition->width = MAX (child_requisition.width, requisition->width);
                 requisition->height = MAX (child_requisition.height, requisition->height);
         }
@@ -490,8 +489,10 @@ nautilus_path_bar_size_request (GtkWidget      *widget,
 		requisition->width += (path_bar->spacing + path_bar->slider_width) * 2;
 	}
 
-        gtk_widget_size_request (path_bar->up_slider_button, &child_requisition);
-        gtk_widget_size_request (path_bar->down_slider_button, &child_requisition);
+	gtk_widget_get_preferred_size (path_bar->up_slider_button,
+				       &child_requisition, NULL);
+	gtk_widget_get_preferred_size (path_bar->down_slider_button,
+				       &child_requisition, NULL);
 
 	border_width = gtk_container_get_border_width (GTK_CONTAINER (widget));
         requisition->width += border_width * 2;
@@ -572,12 +573,14 @@ nautilus_path_bar_size_allocate (GtkWidget     *widget,
 		width = 0;
 	}
 
-	gtk_widget_get_child_requisition (BUTTON_DATA (path_bar->button_list->data)->button, &child_requisition);
+	gtk_widget_get_preferred_size (BUTTON_DATA (path_bar->button_list->data)->button,
+				       &child_requisition, NULL);
 	width += child_requisition.width;
 
         for (list = path_bar->button_list->next; list; list = list->next) {
         	child = BUTTON_DATA (list->data)->button;
-		gtk_widget_get_child_requisition (child, &child_requisition);
+		gtk_widget_get_preferred_size (child,
+					       &child_requisition, NULL);
                 width += child_requisition.width + path_bar->spacing;
 
 		if (list == path_bar->fake_root) {
@@ -609,12 +612,14 @@ nautilus_path_bar_size_allocate (GtkWidget     *widget,
        		* button, then count backwards.
        		*/
       		/* Count down the path chain towards the end. */
-		gtk_widget_get_child_requisition (BUTTON_DATA (first_button->data)->button, &child_requisition);
+		gtk_widget_get_preferred_size (BUTTON_DATA (first_button->data)->button,
+					       &child_requisition, NULL);
                 width = child_requisition.width;
                 list = first_button->prev;
                 while (list && !reached_end) {
 	  		child = BUTTON_DATA (list->data)->button;
-			gtk_widget_get_child_requisition (child, &child_requisition);
+			gtk_widget_get_preferred_size (child,
+						       &child_requisition, NULL);
 
 	  		if (width + child_requisition.width + path_bar->spacing + slider_space > allocation_width) {
 	    			reached_end = TRUE;
@@ -633,7 +638,8 @@ nautilus_path_bar_size_allocate (GtkWidget     *widget,
 
                 while (first_button->next && ! reached_end) {
 	  		child = BUTTON_DATA (first_button->next->data)->button;
-			gtk_widget_get_child_requisition (child, &child_requisition);
+			gtk_widget_get_preferred_size (child,
+						       &child_requisition, NULL);
 
 	  		if (width + child_requisition.width + path_bar->spacing + slider_space > allocation_width) {
 	      			reached_end = TRUE;
@@ -667,7 +673,8 @@ nautilus_path_bar_size_allocate (GtkWidget     *widget,
 
         for (list = first_button; list; list = list->prev) {
                 child = BUTTON_DATA (list->data)->button;
-		gtk_widget_get_child_requisition (child, &child_requisition);
+		gtk_widget_get_preferred_size (child,
+					       &child_requisition, NULL);
 
 		gtk_widget_get_allocation (widget, &widget_allocation);
 
@@ -1571,19 +1578,14 @@ button_data_file_changed (NautilusFile *file,
 	} else if (nautilus_file_is_gone (file)) {
 		gint idx, position;
 
-		/* if the current location is gone, don't do anything, as the view
-		 * will get the event too and call us back.
-		 */
-		if (nautilus_file_compare_location (file, current_button_data->file) != 0) {
-			/* remove this and the following buttons */
-			position = g_list_position (path_bar->button_list,
-						    g_list_find (path_bar->button_list, button_data));
+		/* remove this and the following buttons */
+		position = g_list_position (path_bar->button_list,
+					    g_list_find (path_bar->button_list, button_data));
 
-			if (position != -1) {
-				for (idx = 0; idx <= position; idx++) {
-					gtk_container_remove (GTK_CONTAINER (path_bar),
-							      BUTTON_DATA (path_bar->button_list->data)->button);
-				}
+		if (position != -1) {
+			for (idx = 0; idx <= position; idx++) {
+				gtk_container_remove (GTK_CONTAINER (path_bar),
+						      BUTTON_DATA (path_bar->button_list->data)->button);
 			}
 		}
 
