@@ -140,7 +140,8 @@ nautilus_side_pane_size_allocate (GtkWidget *widget,
 	frame = pane->details->title_frame;
 	hbox = pane->details->title_hbox;
 
-	gtk_widget_get_child_requisition (hbox, &child_requisition);
+	gtk_widget_get_preferred_size (hbox,
+				       &child_requisition, NULL);
 	width = child_requisition.width;
 
 	gtk_widget_get_allocation (frame, &frame_allocation);
@@ -242,7 +243,8 @@ select_button_press_callback (GtkWidget *widget,
                 gtk_widget_get_allocation (widget, &allocation);
                 width = allocation.width;
                 gtk_widget_set_size_request (side_pane->details->menu, -1, -1);
-                gtk_widget_size_request (side_pane->details->menu, &requisition);
+                gtk_widget_get_preferred_size (side_pane->details->menu,
+					       &requisition, NULL);
                 gtk_widget_set_size_request (side_pane->details->menu,
                                              MAX (width, requisition.width), -1);
 
@@ -267,10 +269,10 @@ select_button_key_press_callback (GtkWidget *widget,
 	
 	side_pane = NAUTILUS_SIDE_PANE (user_data);
 
-	if (event->keyval == GDK_space || 
-	    event->keyval == GDK_KP_Space ||
-	    event->keyval == GDK_Return ||
-	    event->keyval == GDK_KP_Enter) {
+	if (event->keyval == GDK_KEY_space || 
+	    event->keyval == GDK_KEY_KP_Space ||
+	    event->keyval == GDK_KEY_Return ||
+	    event->keyval == GDK_KEY_KP_Enter) {
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), TRUE);
 		gtk_menu_popup (GTK_MENU (side_pane->details->menu),
 				NULL, NULL, menu_position_under, widget, 
