@@ -607,8 +607,10 @@ menu_popup_pos (GtkMenu   *menu,
 
 	widget = user_data;
 
-	gtk_widget_size_request (GTK_WIDGET (menu), &menu_requisition);
-	gtk_widget_size_request (widget, &button_requisition);
+	gtk_widget_get_preferred_size (GTK_WIDGET (menu),
+				       &menu_requisition, NULL);
+	gtk_widget_get_preferred_size (widget,
+				       &button_requisition, NULL);
 	gtk_widget_get_allocation (widget, &allocation);
 
 	gdk_window_get_origin (gtk_widget_get_window (widget), x, y);
@@ -964,8 +966,6 @@ nautilus_spatial_window_init (NautilusSpatialWindow *window)
 	pane = nautilus_window_pane_new (win);
 	win->details->panes = g_list_prepend (win->details->panes, pane);
 
-	window->affect_spatial_window_on_next_location_change = TRUE;
-
 	vbox = gtk_vbox_new (FALSE, 0);
 	gtk_table_attach (GTK_TABLE (NAUTILUS_WINDOW (window)->details->table),
 			  vbox,
@@ -1086,10 +1086,10 @@ nautilus_spatial_window_class_init (NautilusSpatialWindowClass *klass)
 	G_OBJECT_CLASS (klass)->finalize = nautilus_spatial_window_finalize;
 
 	binding_set = gtk_binding_set_by_class (klass);
-	gtk_binding_entry_add_signal (binding_set, GDK_BackSpace, GDK_SHIFT_MASK,
+	gtk_binding_entry_add_signal (binding_set, GDK_KEY_BackSpace, GDK_SHIFT_MASK,
 				      "go_up", 1,
 				      G_TYPE_BOOLEAN, TRUE);
-	gtk_binding_entry_add_signal (binding_set, GDK_Up, GDK_SHIFT_MASK | GDK_MOD1_MASK,
+	gtk_binding_entry_add_signal (binding_set, GDK_KEY_Up, GDK_SHIFT_MASK | GDK_MOD1_MASK,
 				      "go_up", 1,
 				      G_TYPE_BOOLEAN, TRUE);
 
